@@ -635,6 +635,12 @@ QString Address::formattedAddress(const QString &realName, const QString &orgaNa
     // now add the country line if needed (formatting this time according to
     // the rules of our own system country )
     if (!country().isEmpty()) {
+
+        // Don't include line breaks if country is the only text
+        if (ret.isEmpty()) {
+            return country().toUpper();
+        }
+
         KConfigGroup group = entry.group(countryCodeFromLocale());
         QString cpos = group.readEntry("AddressCountryPosition");
         if (QLatin1String("BELOW") == cpos || cpos.isEmpty()) {
