@@ -21,7 +21,7 @@
 #include "email.h"
 
 #include <QMap>
-#include <qstringlist.h>
+#include <QStringList>
 #include <QDataStream>
 
 using namespace KContacts;
