@@ -23,7 +23,7 @@
 
 #include <QFile>
 
-#include <qdebug.h>
+#include <QDebug>
 #include <QCoreApplication>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
